package Enbugger::ptkdb;
$Enbugger::ptkdb::VERSION = '2.014';
# COPYRIGHT AND LICENCE
#
# Copyright (C) 2007,2008 WhitePages.com, Inc. with primary
# development by Joshua ben Jore.
#
# This program is distributed WITHOUT ANY WARRANTY, including but not
# limited to the implied warranties of merchantability or fitness for
# a particular purpose.
#
# The program is free software.  You may distribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation (either version 2 or any later version)
# and the Perl Artistic License as published by O’Reilly Media, Inc.
# Please open the files named gpl-2.0.txt and Artistic for a copy of
# these licenses.

use strict;
use warnings;

warn __PACKAGE__ . ' is not implemented';

# sub debugger {
#     package DB;
#     my $class = caller;
#     ## no critic eval
#     eval <<"PTKDB";
#         package $class;
#         require Devel::ptkdb;
#         Enbugger::_load_source();
# PTKDB
# }
# 
# sub stop { warn q(Can't stop) }

() = -.0

## Local Variables:
## mode: cperl
## mode: auto-fill
## cperl-indent-level: 4
## End:

